@@ -116,7 +116,7 @@ class ProcessList(BaseModel):
         if values['autorun'] is False:
             values['autorun'] = '[red]disabled[/red]'
         elif values['autorun'] and values['autorun_exclude']:
-            values['autorun'] = '[yellow]sospended[/yellow]'
+            values['autorun'] = '[yellow]suspended[/yellow]'
         elif values['autorun'] and not values['autorun_exclude']:
             values['autorun'] = '[green]enabled[/green]'
         return values
@@ -124,7 +124,7 @@ class ProcessList(BaseModel):
 
 class Process(BaseModel):
     # Struttura vera del processo
-    pm3_id: int
+    pm3_id: int = None  # None significa che deve essere assegnato da next_id()
     pm3_name: str
     cmd: str
     cwd: str = Path.home().as_posix()
